@@ -65,6 +65,19 @@ class DetectedRequirement(object):
             self.url = url
             self.requirement = None
 
+    def _format_specs(self):
+        return ','.join(['%s%s' % (comp, version) for comp, version in self.version_specs])
+
+    def pip_format(self):
+        if self.url:
+            if self.name:
+                return '%s#egg=%s' % (self.url, self.name)
+            return self.url
+        if self.name:
+            if self.version_specs:
+                return "%s%s" % (self.name, self._format_specs())
+            return self.name
+
     def __str__(self):
         rep = self.name or 'Unknown'
         if self.version_specs:
@@ -101,8 +114,11 @@ class DetectedRequirement(object):
         # if it is a VCS URL, then we want to strip off the protocol as urlparse
         # might not handle it correctly
         vcs_scheme = None
-        if '+' in url.scheme:
-            vcs_scheme = url.scheme
+        if '+' in url.scheme or url.scheme in ('git',):
+            if url.scheme == 'git':
+                vcs_scheme = 'git+git'
+            else:
+                vcs_scheme = url.scheme
             url = urlparse.urlparse(re.sub(r'^%s://' % re.escape(url.scheme), '', line))
 
         if vcs_scheme is None and url.scheme == '' and not _is_filepath(line):
